Module: Ibandit

Defined in:
lib/ibandit/german_details_converter.rb,
lib/ibandit.rb,
lib/ibandit/iban.rb,
lib/ibandit/errors.rb,
lib/ibandit/version.rb,
lib/ibandit/check_digit.rb,
lib/ibandit/iban_builder.rb

Overview

German bank details don't map directly to IBANs in the same way as in other countries - each bank has idiosyncracies for translating its cusomers' bank details. These idiosyncracies are described in a document from the Bundesbank: http://www.bundesbank.de/Navigation/DE/Aufgaben/Unbarer_Zahlungsverkehr/IBAN_Regeln/iban_regeln.html

Defined Under Namespace

Modules: CheckDigit, GermanDetailsConverter, IBANBuilder Classes: BicNotFoundError, IBAN, InvalidCharacterError, UnsupportedAccountDetails, UnsupportedCountryError

Constant Summary collapse

VERSION =
'0.2.0'.freeze

Class Attribute Summary collapse

Class Method Summary collapse

Class Attribute Details

.bic_finder ⇒ Object

Returns the value of attribute bic_finder.



10
11
12
# File 'lib/ibandit.rb', line 10

def bic_finder
  @bic_finder
end

Class Method Details

.find_bic(country_code, national_id) ⇒ Object

Raises:

  • (NotImplementedError)


12
13
14
15
# File 'lib/ibandit.rb', line 12

def find_bic(country_code, national_id)
  raise NotImplementedError, 'BIC finder is not defined' unless @bic_finder
  @bic_finder.call(country_code, national_id)
end